@@ -201,7 +201,6 @@ static void hildon_im_fcitx_fkb_init       (HildonIMFcitxFKB *self);
 static void populate_window (HildonIMFcitxFKB *self);
 static void button_update ( HildonIMFcitxFKBPrivate *priv, const gchar** keyboard_layout[]);
 static void close_fkb (GtkWidget *button, gpointer user_data);
-static void power_off_save_data();
 /*
  * Module functions
  */
@@ -619,7 +618,7 @@ delete_selection (gpointer data)
 }
 static void show_candwords(HildonIMFcitxFKBPrivate *priv)
 {
-  gchar tmp[100];
+  gchar tmp[MAX_USER_INPUT + 1];
   gchar *wd = tmp;
   tmp[0] = '\0';
   if(iPYInsertPoint){
@@ -773,6 +772,8 @@ static void
 button_update ( HildonIMFcitxFKBPrivate *priv, const gchar** keyboard_layout[])
 {
   GtkWidget *labelchild;
+  gchar *fontname = "Nokia Sans 24";
+  if(gdk_screen_width() == 480) fontname = "Nokia Sans 20";
   PangoFontDescription *font = pango_font_description_from_string("Nokia Sans 24");
   gint i,j;
   for (i = 0; keyboard_layout[i] != NULL; i++)
@@ -1042,8 +1043,10 @@ populate_window (HildonIMFcitxFKB *self)
   HildonIMFcitxFKBPrivate *priv;
   GtkWidget *parea, *labelchild;
   gint button_width = gdk_screen_width() / 10;
-  PangoFontDescription *font = pango_font_description_from_string("Nokia Sans 24");
-
+  gint fix_height = (button_width == 80)? 0:30;
+  gchar *fontname = "Nokia Sans 24";
+  if(button_width == 48) fontname = "Nokia Sans 20";
+  PangoFontDescription *font = pango_font_description_from_string(fontname);
   priv = HILDON_IM_FCITX_FKB_GET_PRIVATE(self);
   priv->vbox = gtk_vbox_new(FALSE, 1);
 
@@ -1093,7 +1096,7 @@ populate_window (HildonIMFcitxFKB *self)
   {
         priv->buttons[3][i] = gtk_button_new();
         gtk_button_set_focus_on_click(GTK_BUTTON(priv->buttons[3][i]),FALSE);
-        g_signal_connect(G_OBJECT(priv->buttons[3][i]), "pressed", G_CALLBACK(text_button_clicked), self);
+        g_signal_connect(G_OBJECT(priv->buttons[3][i]), "clicked", G_CALLBACK(text_button_clicked), self);
         gtk_box_pack_start(GTK_BOX(priv->buttons[3][2]), GTK_WIDGET(priv->buttons[3][i]), TRUE, TRUE, 0);
   }
   gtk_box_pack_start(GTK_BOX(priv->vbox), priv->buttons[3][2], FALSE, FALSE, 0);
@@ -1103,7 +1106,7 @@ populate_window (HildonIMFcitxFKB *self)
     GtkWidget *hbox  = gtk_hbox_new(FALSE, 0);
     if (i == 1){
         GtkWidget *label = gtk_label_new(" ");
-        gtk_widget_set_size_request(label, button_width*0.5, BUTTON_HEIGHT);
+        gtk_widget_set_size_request(label, button_width*0.5, BUTTON_HEIGHT+fix_height);
         gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
     }
     else if (i == 2){
@@ -1112,7 +1115,7 @@ populate_window (HildonIMFcitxFKB *self)
         gtk_container_add (GTK_CONTAINER (priv->shift_button),
                           gtk_image_new_from_icon_name("keyboard_shift",
                                                        -1));
-        gtk_widget_set_size_request(priv->shift_button, button_width*1.5, BUTTON_HEIGHT);
+        gtk_widget_set_size_request(priv->shift_button, button_width*1.5, BUTTON_HEIGHT+fix_height);
         gtk_box_pack_start(GTK_BOX(hbox), priv->shift_button, FALSE, FALSE, 0);
         g_signal_connect(G_OBJECT(priv->shift_button), "toggled", G_CALLBACK(shift_symbols_buttons_toggled), self);
     }
@@ -1121,7 +1124,7 @@ populate_window (HildonIMFcitxFKB *self)
 
       priv->symbols_button = gtk_toggle_button_new_with_label ("符");
       gtk_button_set_focus_on_click(GTK_BUTTON(priv->symbols_button),FALSE);
-      gtk_widget_set_size_request(priv->symbols_button, button_width*1.5, BUTTON_HEIGHT);
+      gtk_widget_set_size_request(priv->symbols_button, button_width*1.5, BUTTON_HEIGHT+fix_height);
       gtk_box_pack_start(GTK_BOX(hbox), priv->symbols_button, FALSE, FALSE, 0);
       g_signal_connect(priv->symbols_button, "toggled",
                    G_CALLBACK(shift_symbols_buttons_toggled), self);
@@ -1130,7 +1133,7 @@ populate_window (HildonIMFcitxFKB *self)
 
       priv->mode_button = gtk_button_new_with_label (chinese_mode?"拼":"英");
       gtk_button_set_focus_on_click(GTK_BUTTON(priv->mode_button),FALSE);
-      gtk_widget_set_size_request(priv->mode_button, button_width, BUTTON_HEIGHT);
+      gtk_widget_set_size_request(priv->mode_button, button_width, BUTTON_HEIGHT+fix_height);
       gtk_box_pack_start(GTK_BOX(hbox), priv->mode_button, FALSE, FALSE, 0);
       g_signal_connect(priv->mode_button, "clicked", G_CALLBACK(switch_button_clicked), self);
 
@@ -1147,7 +1150,7 @@ populate_window (HildonIMFcitxFKB *self)
         gtk_button_set_focus_on_click(GTK_BUTTON(priv->buttons[i][j]),FALSE);
         labelchild = gtk_bin_get_child(GTK_BIN(priv->buttons[i][j]));
         gtk_widget_modify_font(GTK_WIDGET(labelchild),font);
-        gtk_widget_set_size_request(GTK_WIDGET(priv->buttons[i][j]),button_width,BUTTON_HEIGHT);
+        gtk_widget_set_size_request(GTK_WIDGET(priv->buttons[i][j]),button_width,BUTTON_HEIGHT+fix_height);
         g_signal_connect(G_OBJECT(priv->buttons[i][j]), "pressed", G_CALLBACK(text_button_clicked), self);
         gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(priv->buttons[i][j]), FALSE, FALSE, 0);
     }
@@ -1157,7 +1160,7 @@ populate_window (HildonIMFcitxFKB *self)
         gtk_button_set_image(GTK_BUTTON(priv->delete_button),
                           gtk_image_new_from_icon_name("keyboard_backspace",
                                                        1));
-        gtk_widget_set_size_request(priv->delete_button, button_width*1.5, BUTTON_HEIGHT);
+        gtk_widget_set_size_request(priv->delete_button, button_width*1.5, BUTTON_HEIGHT+fix_height);
         g_signal_connect(G_OBJECT(priv->delete_button), "pressed", G_CALLBACK(backspace_pressed), self);
         g_signal_connect(G_OBJECT(priv->delete_button), "released", G_CALLBACK(backspace_released), self);
         gtk_box_pack_start(GTK_BOX(hbox), priv->delete_button, FALSE, FALSE, 0);
@@ -1170,7 +1173,7 @@ populate_window (HildonIMFcitxFKB *self)
       gtk_button_set_image(GTK_BUTTON(priv->return_button),
                           gtk_image_new_from_icon_name("keyboard_enter",
                                                        -1));
-      gtk_widget_set_size_request(priv->return_button, button_width*1.5, BUTTON_HEIGHT);
+      gtk_widget_set_size_request(priv->return_button, button_width*1.5, BUTTON_HEIGHT+fix_height);
       gtk_box_pack_start(GTK_BOX(hbox), priv->return_button, FALSE, FALSE, 0);
       g_signal_connect(priv->return_button, "clicked", G_CALLBACK(return_button_clicked), self);
     }
